tear-pages
==========

Simple script to remove the first page of a PDF

Why?
====

Because many pdf providers such as scientific publishers like to add a useless cover page.
I don't want to:

* print the first page and sometimes I can forget to select the page range
* to scroll down to read the file

How to use?
===========

It's dead simple

    tearpages.py file.pdf

Install
=======

First, install pyPDF2 from http://mstamy2.github.io/PyPDF2/

AUR
----

* https://aur.archlinux.org/packages/tear-pages/

Pypi
----

* https://pypi.python.org/pypi/tear-pages

git and sources
---------------

* http://github.com/sciunto/tear-pages
* https://git.sciunto.org/mirror/tear-pages

License
=======

GPLv3. Read LICENSE for more details.

Authors
=======

* François Boulogne.
